import { r as registerInstance, h, g as getElement, H as Host } from './index-4369d317.js';

const codeCss = ":host{display:block}pre{margin:0}.code{display:block;padding:var(--gap-xs) var(--gap-sm) var(--gap-sm);border:1px solid rgba(var(--violet-rgb), .2);border-radius:.6rem;background-color:#f8f9fa;color:#222;font-size:1.4rem;line-height:1.4;overflow-x:auto}.code--example{border-top-right-radius:0;border-top-left-radius:0}.code__title{margin:0 0 var(--gap-sm);color:#555;font-weight:300;font-size:1.3rem;text-transform:uppercase;font-family:monospace}";

const BSWCCode = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.language = 'HTML';
    this.hasExample = undefined;
  }
  formatHtml(content) {
    let string = content.replaceAll('<!---->', '');
    string = string.replaceAll(' class="hydrated"', '');
    let array = string.split('> <');
    array = array.map((element, index) => {
      const isFirst = index === 0;
      const isLast = index === array.length - 1;
      let html = '';
      if (!isFirst) {
        html += '<';
      }
      html += element;
      if (!isLast) {
        html += '>';
      }
      return html;
    });
    return array;
  }
  render() {
    const code = this.formatHtml(this.element.innerHTML);
    return (h("div", { class: 'code ' + (this.hasExample ? 'code--example' : '') }, h("h5", { class: "code__title" }, this.language), code.map(tag => {
      return h("pre", null, h("code", null, tag.includes('bwc-row') ? tag : '  ' + tag));
    })));
  }
  get element() { return getElement(this); }
};
BSWCCode.style = codeCss;

const sectionCss = ":host{display:block}a{color:var(--link-color)}.section__title{margin:0 0 var(--gap-sm);font-size:2rem;font-weight:500}.section__info{color:#555;font-size:1.4rem}.section__info>a::after{content:\" ↗️\"}.section__example{padding:var(--gap-sm) var(--gap-sm) var(--gap);border:1px solid rgba(var(--violet-rgb), .2);border-bottom:none;border-radius:.6rem;border-bottom-left-radius:0;border-bottom-right-radius:0;background-color:rgba(var(--violet-rgb), 0.02)}.section__example-title{margin:0 0 var(--gap-sm);color:#555;font-weight:300;font-size:1.3rem;text-transform:uppercase;font-family:monospace}.section__example-content{margin:0 var(--gap-sm)}.section>*+*{margin-top:var(--gap-sm)}";

const BSWCSection = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.heading = undefined;
    this.slug = undefined;
    this.hasExample = true;
    this.language = '';
  }
  getCode(content) {
    return content;
  }
  render() {
    const code = this.getCode(this.element.innerHTML);
    return (h("section", { class: "section" }, h("h4", { class: "section__title" }, this.heading), h("div", null, this.hasExample ?
      h("div", { class: "section__example" }, h("div", { class: "section__example-title" }, "Example"), h("div", { class: "section__example-content" }, h("slot", null)))
      : '', h("bswc-code", { innerHTML: code, "has-example": this.hasExample, language: this.language })), this.slug ?
      h("p", { class: "section__info" }, "More info about ", h("a", { href: `https://getbootstrap.com/docs/5.3/layout/grid/#${this.slug}`, target: "_blank" }, this.heading), " at Bootstrap website.")
      : ''));
  }
  get element() { return getElement(this); }
};
BSWCSection.style = sectionCss;

const BWCCol = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return (h(Host, null, h("slot", null)));
  }
};

const BWCRow = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return (h(Host, null, h("slot", null)));
  }
};

export { BSWCCode as bswc_code, BSWCSection as bswc_section, BWCCol as bwc_col, BWCRow as bwc_row };

//# sourceMappingURL=bswc-code_4.entry.js.map